You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@commons.apache.org by gg...@apache.org on 2006/09/20 18:53:54 UTC

svn commit: r448263 - /jakarta/commons/proper/lang/trunk/src/java/org/apache/commons/lang/builder/ToStringBuilder.java

Author: ggregory
Date: Wed Sep 20 09:53:53 2006
New Revision: 448263

URL: http://svn.apache.org/viewvc?view=rev&rev=448263
Log:
The parameter object is hiding a field from type ToStringBuilder.

Modified:
    jakarta/commons/proper/lang/trunk/src/java/org/apache/commons/lang/builder/ToStringBuilder.java

Modified: jakarta/commons/proper/lang/trunk/src/java/org/apache/commons/lang/builder/ToStringBuilder.java
URL: http://svn.apache.org/viewvc/jakarta/commons/proper/lang/trunk/src/java/org/apache/commons/lang/builder/ToStringBuilder.java?view=diff&rev=448263&r1=448262&r2=448263
==============================================================================
--- jakarta/commons/proper/lang/trunk/src/java/org/apache/commons/lang/builder/ToStringBuilder.java (original)
+++ jakarta/commons/proper/lang/trunk/src/java/org/apache/commons/lang/builder/ToStringBuilder.java Wed Sep 20 09:53:53 2006
@@ -443,11 +443,11 @@
      * <p>Append to the <code>toString</code> an <code>Object</code>
      * value.</p>
      *
      * @param object  the value to add to the <code>toString</code>
      * @return this
      */
-    public ToStringBuilder append(Object object) {
-        style.append(buffer, null, object, null);
+    public ToStringBuilder append(Object obj) {
+        style.append(buffer, null, obj, null);
         return this;
     }
 
@@ -819,11 +819,11 @@
      * value.</p>
      *
      * @param fieldName  the field name
      * @param object  the value to add to the <code>toString</code>
      * @return this
      */
-    public ToStringBuilder append(String fieldName, Object object) {
-        style.append(buffer, fieldName, object, null);
+    public ToStringBuilder append(String fieldName, Object obj) {
+        style.append(buffer, fieldName, obj, null);
         return this;
     }
 
@@ -832,13 +832,13 @@
      * value.</p>
      *
      * @param fieldName  the field name
      * @param object  the value to add to the <code>toString</code>
      * @param fullDetail  <code>true</code> for detail,
      *  <code>false</code> for summary info
      * @return this
      */
-    public ToStringBuilder append(String fieldName, Object object, boolean fullDetail) {
-        style.append(buffer, fieldName, object, BooleanUtils.toBooleanObject(fullDetail));
+    public ToStringBuilder append(String fieldName, Object obj, boolean fullDetail) {
+        style.append(buffer, fieldName, obj, BooleanUtils.toBooleanObject(fullDetail));
         return this;
     }
 



---------------------------------------------------------------------
@@ -443,11 +443,11 @@
      * value.</p>
      *
-     * @param object  the value to add to the <code>toString</code>
+     * @param obj  the value to add to the <code>toString</code>
      * @return this
      */
@@ -819,11 +819,11 @@
      *
      * @param fieldName  the field name
-     * @param object  the value to add to the <code>toString</code>
+     * @param obj  the value to add to the <code>toString</code>
      * @return this
      */
@@ -832,13 +832,13 @@
      *
      * @param fieldName  the field name
-     * @param object  the value to add to the <code>toString</code>
+     * @param obj  the value to add to the <code>toString</code>
      * @param fullDetail  <code>true</code> for detail,
      *  <code>false</code> for summary info
To unsubscribe, e-mail: commons-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: commons-dev-help@jakarta.apache.org